@@ -1,5 +1,5 @@
 # ************************************************************************* 
-# Copyright (c) 2014, SUSE LLC
+# Copyright (c) 2014-2015, SUSE LLC
 # 
 # All rights reserved.
 # 
@@ -52,16 +52,6 @@ App::CELL::Load -- find and load message files and config files
 
 
 
-=head1 VERSION
-
-Version 0.210
-
-=cut
-
-our $VERSION = '0.210';
-
-
-
 =head1 SYNOPSIS
  
     use App::CELL::Load;
@@ -165,7 +155,7 @@ sub init {
     $meta->set('CELL_META_LOAD_VERBOSE', $ARGS{'verbose'} || 0);
 
     $log->info( "Entering App::CELL::Load::init " . 
-        "version $VERSION from " . (caller)[0] . " $args_string",
+        "from " . (caller)[0] . " $args_string",
         cell => 1) if $meta->CELL_META_LOAD_VERBOSE;
 
     # check for taint mode
