@@ -197,8 +197,7 @@ sub populate_file {
     my ( $full_path, $contents ) = @_;
     unlink $full_path;
     {
-        use File::Touch;
-        File::Touch::touch( $full_path ) or die "Could not touch $full_path";
+        _touch( $full_path ) or die "Could not touch $full_path";
     }
     return 0 unless -f $full_path and -W $full_path;
     return 0 unless $contents;
